@@ -11,7 +11,7 @@ use Exporter qw(import);
 
 our( @EXPORT, @EXPORT_OK, %EXPORT_TAGS );
 
-our $VERSION = '0.906';
+our $VERSION = '0.907';
 
 =encoding utf8
 
@@ -76,6 +76,8 @@ I don't really know what this does.
 
 =item * bg_magenta
 
+=item * bg_orange
+
 =item * bg_red
 
 =item * bg_white
@@ -227,6 +229,8 @@ This dies if N is not a positive number between 0 and 255 (inclusive).
 
 =item * text_magenta
 
+=item * text_orange
+
 =item * text_red
 
 =item * text_rgb
@@ -447,6 +451,23 @@ BEGIN {
 			_export( $name, $group->[1] );
 			}
 		}
+
+	my @secondary_colors = (
+		[ 'orange', [ 0xFF, 0x8C, 0x00 ] ],
+		);
+
+	foreach my $tuple ( @secondary_colors ) {
+		no strict 'refs';
+		my( $color, $rgb ) = $tuple->@*;
+		my $name = "text_$color";
+		my $value = text_rgb( $rgb->@* );
+		*{$name} = sub () { $value };
+		_export( $name, 'text' );
+
+		$name = "bg_$color";
+		$value = bg_rgb( $rgb->@* );
+		_export( $name, 'bg' );
+		}
 	}
 
 =head2 Character shortcuts
